aboutsummaryrefslogtreecommitdiff
path: root/BuildScripts
diff options
context:
space:
mode:
authorGravatar thomasvl@gmail.com <thomasvl@gmail.com@7dc7ac4e-7543-0410-b95c-c1676fc8e2a3>2008-09-22 23:33:44 +0000
committerGravatar thomasvl@gmail.com <thomasvl@gmail.com@7dc7ac4e-7543-0410-b95c-c1676fc8e2a3>2008-09-22 23:33:44 +0000
commit7bb8e9b9b24141f373ed70d7e6674a245c0227cf (patch)
tree8fab3cad46943aee24f213e041b2a7f6b71ea5df /BuildScripts
parentbfaf8705cccb15c0c2a7704b17ba011ddba8242f (diff)
- Added GTMTestTimer.h for doing high fidelity timings.
- Added leaks checking to iPhone unit test script. It can be controlled by the GTM_DISABLE_LEAKS environment variable - Added ability to control using zombies to iPhone unit test script. It can be controlled by the GTM_DISABLE_ZOMBIES environment variable - Added ability to control termination to iPhone unit test script. It can be controlled by the GTM_DISABLE_TERMINATION environment variable - Fixed several leaks found with leak checking enabled. - Added configs for different iPhone OS versions.
Diffstat (limited to 'BuildScripts')
-rwxr-xr-xBuildScripts/BuildAllSDKs.sh35
1 files changed, 27 insertions, 8 deletions
diff --git a/BuildScripts/BuildAllSDKs.sh b/BuildScripts/BuildAllSDKs.sh
index 0928dcd..1e08940 100755
--- a/BuildScripts/BuildAllSDKs.sh
+++ b/BuildScripts/BuildAllSDKs.sh
@@ -1,7 +1,7 @@
#!/bin/sh
# BuildAllSDKs.sh
#
# This script builds both the Tiger and Leopard versions of the requested
# target in the current basic config (debug, release, debug-gcov).
#
# Copyright 2006-2008 Google Inc.
@@ -18,21 +18,37 @@
# License for the specific language governing permissions and limitations under
# the License.
-PROJECT_TARGET="$1"
+GTM_PROJECT_TARGET="$1"
+GTMIPHONE_PROJECT_TARGET="$2"
STARTING_TARGET="${TARGET_NAME}"
SCRIPT_APP="${TMPDIR}DoBuild.app"
-REQUESTED_BUILD_STYLE=$(echo "${BUILD_STYLE}" | sed "s/.*OrLater-\(.*\)/\1/")
+REQUESTED_BUILD_STYLE=$(echo "${BUILD_STYLE}" | sed -E "s/(.*OrLater-)?(.*)/\2/")
# See if we were told to clean instead of build.
PROJECT_ACTION="build"
if [ "${ACTION}" == "clean" ]; then
PROJECT_ACTION="clean"
fi
-# build up our AppleScript
+# build up our GTMiPhone parts
+GTMIPHONE_OPEN_EXTRAS=""
+GTMIPHONE_BUILD_EXTRAS=""
+if [ "${GTMIPHONE_PROJECT_TARGET}" != "" ]; then
+ GTMIPHONE_OPEN_EXTRAS="-- make sure both project files are open
+ open posix file \"${SRCROOT}/GTM.xcodeproj\"
+ open posix file \"${SRCROOT}/GTMiPhone.xcodeproj\""
+ GTMIPHONE_BUILD_EXTRAS="tell project \"GTMiPhone\"
+ -- do the GTMiPhone build
+ ${PROJECT_ACTION} using build configuration \"${REQUESTED_BUILD_STYLE}\"
+ set active target to target \"${STARTING_TARGET}\"
+ end tell"
+fi
+
+# build up our GTM AppleScript
OUR_BUILD_SCRIPT="on run
tell application \"Xcode\"
activate
+ ${GTMIPHONE_OPEN_EXTRAS}
tell project \"GTM\"
-- wait for build to finish
set x to 0
@@ -44,19 +60,22 @@ OUR_BUILD_SCRIPT="on run
return
end if
end repeat
- -- do the build
+ -- do the GTM builds
with timeout of 9999 seconds
- set active target to target \"${PROJECT_TARGET}\"
+ set active target to target \"${GTM_PROJECT_TARGET}\"
set buildResult to ${PROJECT_ACTION} using build configuration \"TigerOrLater-${REQUESTED_BUILD_STYLE}\"
if buildResult is not equal to \"Build succeeded\" then
set active target to target \"${STARTING_TARGET}\"
return
end if
- -- do not need the result since we are not doing another build
- ${PROJECT_ACTION} using build configuration \"LeopardOrLater-${REQUESTED_BUILD_STYLE}\"
+ set buildResult to ${PROJECT_ACTION} using build configuration \"LeopardOrLater-${REQUESTED_BUILD_STYLE}\"
set active target to target \"${STARTING_TARGET}\"
+ if buildResult is not equal to \"Build succeeded\" then
+ return
+ end if
end timeout
end tell
+ ${GTMIPHONE_BUILD_EXTRAS}
end tell
end run"
@@ -1,7 +1,7 @@
# BuildAllSDKs.sh
#
-# This script builds both the Tiger and Leopard versions of the requested
+# This script builds the Tiger, Leopard and iPhone versions of the requested
# target in the current basic config (debug, release, debug-gcov).
#